@@ -9,10 +9,14 @@
 """
 from django.shortcuts import render
 
-from apiview_doc.decorator import api_doc
+from apiview_doc.openapi import OpenApi, api_info_list
+
+openapi = OpenApi(
+    paths = api_info_list()
+)
 
 
-def docs(request):
-    context = api_doc()
+def get_openapi_docs_url(request):
+    context = openapi.__dict__
 
-    return render(request, 'apiview_doc/docs/index.html', context)
+    return render(request, 'apiview_doc/openapi/index.html', context)
